<?php

namespace Drupal\path_watcher\EventSubscriber;

use Drupal\path_watcher\PathWatcherManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\TerminateEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Path watcher event subscriber.
 */
class PathWatcherSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a new PathWatcherSubscriber object.
   *
   * @param \Drupal\path_watcher\PathWatcherManagerInterface $pathWatcherManager
   *   The path watcher manager.
   */
  public function __construct(protected PathWatcherManagerInterface $pathWatcherManager) {}

  /**
   * Kernel terminate event handler.
   *
   * @param \Symfony\Component\HttpKernel\Event\TerminateEvent $event
   *   Terminate event.
   */
  public function onKernelTerminate(TerminateEvent $event) {
    if ($this->pathWatcherManager->needSave($event)) {
      $this->pathWatcherManager->saveVisit($event->getRequest()->getPathInfo());
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [KernelEvents::TERMINATE => ['onKernelTerminate']];
  }

}
