<?php

namespace Drupal\path_watcher\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure path watcher settings for this site.
 */
class PathWatcherSettingsForm extends ConfigFormBase {

  /**
   * The module config name.
   */
  const CONFIG_NAME = 'path_watcher.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'path_watcher_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [static::CONFIG_NAME];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::CONFIG_NAME);
    $form['skip_admin_paths'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Skip admin paths'),
      '#default_value' => $config->get('skip_admin_paths'),
    ];
    $form['skip_anonymous'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Skip anonymous visits'),
      '#default_value' => $config->get('skip_anonymous'),
    ];
    $usernames = $config->get('skip_usernames');
    $form['skip_usernames'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Skip usernames'),
      '#description' => $this->t('One username per line. Skip visits with these usernames.'),
      '#default_value' => $usernames ? implode(PHP_EOL, $usernames) : '',
      '#rows' => 2,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->cleanValues()->getValues();
    $values['skip_usernames'] = array_filter(array_map('trim', explode(PHP_EOL, $values['skip_usernames'])));
    $this->config(static::CONFIG_NAME)
      ->setData($values)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
