<?php

namespace Drupal\path_watcher;

use Symfony\Component\HttpKernel\Event\TerminateEvent;

/**
 * Provides an interface for a path watcher manager.
 */
interface PathWatcherManagerInterface {

  /**
   * Hash algorithm used to generate the path ID.
   */
  const HASH_ALGO = 'xxh128';

  /**
   * Determine if the visit needs to be saved.
   *
   * @param \Symfony\Component\HttpKernel\Event\TerminateEvent $event
   *   The terminate event.
   *
   * @return bool
   *   TRUE if the visit needs to be saved, FALSE otherwise.
   */
  public function needSave(TerminateEvent $event): bool;

  /**
   * Saves the visit.
   *
   * @param string $path
   *   The path.
   *
   * @return \Drupal\path_watcher\VisitInterface
   *   The saved visit.
   */
  public function saveVisit(string $path): VisitInterface;

  /**
   * Returns the hash of the path.
   *
   * @param string $path
   *   The path.
   *
   * @return string
   *   The hash of the path.
   */
  public function getPathHash(string &$path): string;

  /**
   * Returns the path entity.
   *
   * @param string $path
   *   The path.
   *
   * @return \Drupal\path_watcher\PathInterface
   *   The path entity.
   */
  public function getPathEntity(string $path): PathInterface;

}
